import { useUserinfoStore } from "@/stores/UserinfoStore"

export async function fetchUpdate() {
    if (this.shouldStop || !this.isActive) {
        this.isActive = false
        this.shouldStop = false
        console.debug('engine stopped')
        return
    }

    let delay = 0
    try {
        console.log(`sync[${this.version}]`)
        const userInfoStore = useUserinfoStore()
        const response = await this.callApi('/api/sync', {
            v: this.version + 1,
            g: userInfoStore.gameId,
        })

        if (!Number.isInteger(response.version)) {
            throw Error('unexpected response from /api/sync')
        }

        // TODO: parse answer
        this.version = parseInt(response.version)
    } catch (e) {
        if (e.response) {
            // callApi() threw an exception
            const { status, statusText } = e.response
            if (status == 200) {
                delay = 1000
            } else {
                console.warn(`HTTP ${status} ${statusText}`)
                delay = 5000
                this.version = -1
            }
        } else {
            // request aborted or other causes
            console.warn(e.message)
            return
        }
    }

    window.setTimeout(() => {
        this.fetchUpdate()
    }, delay)
}