import { callApi, QueryParams } from '@/composables/engine/callApi'
import { start, stop } from '@/composables/engine/startStop'
import { fetchUpdate } from '@/composables/engine/fetchUpdate'

interface EngineContext {
    isActive: boolean
    shouldStop: boolean
    version: number
    fetchUpdate: () => void
    callApi: (url: string, queryParams?: QueryParams) => Promise<unknown>
}

export interface useEngine {
    start(): void
    stop(): void
    fetchUpdate(): void
}

export default (): useEngine => {
    const context: EngineContext = {
        isActive: false,
        shouldStop: false,
        version: -1,
        callApi,
        fetchUpdate,
    }

    return {
        start: () => start.apply(context),
        stop: () => stop.apply(context),
        fetchUpdate: () => fetchUpdate.apply(context),
    }
}